timeintervaltools.make_polyphonic_percussion_score_from_nonoverlapping_trees
============================================================================

.. autofunction:: abjad.tools.timeintervaltools.make_polyphonic_percussion_score_from_nonoverlapping_trees.make_polyphonic_percussion_score_from_nonoverlapping_trees
